// Wedge Screw Test print. v1.0

// Use #12 x 3/4" sheet metal screws.

// If you change variables WedgeAngle, BoltDia or BoltDepth, transfer the new values to Telengard Wedge.scad lines 29, 33, and 34.

/////////////////////////////
//  Define the variables
/////////////////////////////

WedgeAngle = 55;  // Wedge angle

BoltDia = 5.2;  // Bolt hole diameter -- default = 5.2
BoltDepth = 19; // Bolt hole depth -- default = 19

CubeX = 14;
CubeY = 14;
CubeZ = 20;

AngledYOffset = 8.6;
AngledZOffset = 2;

SideThick = 1.6;
SideY = 29.0;
SideZ = 7.8;

// Number of fragments (polygon sides) used to render a full circle.
    $fn = 180; // Default = 180  Typical range = 6 - 360
    // 6 will render a circular hole as a hexagon, 8 will render a circular hole as an octagon.
    // Lower the number for faster rendering, raise the number for smoother rendering.


/////////////////////////////
//  Make the part
/////////////////////////////

difference(){ // Upright cube minus screw hole

    translate([0, 0, CubeZ/2])
    cube([CubeX, CubeY, CubeZ], center=true); // Upright cube

    translate([0, 0, CubeZ - BoltDepth/2])
    cylinder (BoltDepth + 0.1, d = BoltDia, center=true); // Screw hole

} // End upright cube minus screw hole
//

difference(){ // Angled cube and sides minus screw hole and bottom flat


    union(){ // Angled cube and sides

        translate([0, AngledYOffset, AngledZOffset])
        rotate ([-WedgeAngle, 0,0])
        translate([0, 0, CubeZ/2])
        cube([CubeX, CubeY, CubeZ], center=true); // Angled cube

        translate([(-CubeX/2) + SideThick/2, SideY/2, SideZ/2])
        cube([SideThick, SideY, SideZ], center=true); // Left side

        translate([(CubeX/2) - SideThick/2, SideY/2, SideZ/2])
        cube([SideThick, SideY, SideZ], center=true); // Right side

    } // End angled cube and sides
    //

    translate([0, AngledYOffset, AngledZOffset])
    rotate ([-WedgeAngle, 0,0])
    translate([0, 0, CubeZ - BoltDepth/2])
    cylinder (BoltDepth + 0.1, d = BoltDia, center=true); // Screw hole

    translate([0, SideY/2, - CubeZ/2])
    cube([CubeX + 2, SideY + 2, CubeZ], center=true); // Bottom flat

} // End angled cube and sides minus screw hole and bottom flat
//